@@ -1,5 +1,5 @@
 /*
- * "$Id: de.c,v 1.21.2.1 1999/02/08 03:10:52 yamasita Exp $"
+ * "$Id: de.c,v 1.21.2.3 1999/04/06 05:41:00 nakanisi Exp $"
  */
 
 /*
@@ -30,8 +30,14 @@
  * Commentary:
  *
  * Change log:
+ *	'99/03/20	һУƣ <kate@pfu.co.jp>
+ *		error1 ΰstderr ;ʬˡ
+ *		ؿ puts_n_cur(p,n) ɲá
+ *	'99/04/06	Hidekazu Kuroki -  (hidekazu@cs.titech.ac.jp)
+ *		#include <sys/param.h> ɲá
+ *		stderr  /dev/null ˤ롣
  *
- * Last modified date: 8,Feb.1999
+ * Last modified date: 06,Apr.1999
  *
  * Code:
  *
@@ -55,6 +61,9 @@ extern int errno;		/* Pure BSD */
 
 #include <sys/ioctl.h>
 
+#if (defined(__unix__) || defined(unix)) && !defined(USG)
+#include <sys/param.h>
+#endif
 #ifdef SYSVR2
 #include <sys/param.h>
 #ifndef SIGCHLD
@@ -254,7 +263,16 @@ char **argv;
 	fclose(stdin);
 	fclose(stdout);
 	if(!noisy){
+#if !(defined(BSD) && (BSD >= 199306)) /* !4.4BSD-Lite by Taoka */
 	    fclose(stderr);
+#else /* 4.4BSD-Lite */
+	    int fd = open("/dev/null", O_WRONLY);
+	    if (fd < 0) {
+		xerror("Cannot open /dev/null\n");
+	    }
+	    dup2(fd, 2);
+	    close(fd);
+#endif /* 4.4BSD-Lite */
 	}
 
 #if defined(hpux) || defined(SOLARIS)
@@ -428,7 +446,7 @@ del_client()
 	bcopy(&client[cur_clp], &client[clientp - 1], sizeof(CLINET));
 #endif /* !IBM */
 	clientp--;
-	error1(stderr,"Delete Client: cur_clp = %d\n", cur_clp);
+	error1("Delete Client: cur_clp = %d\n", cur_clp);
 }
 
 
@@ -641,6 +659,17 @@ char *p;
     putc_cur(0);
 }
 
+/**	**/
+void
+puts_n_cur(p,n)
+char *p;
+int n;
+{
+    register int c;
+    while((c = *p++) && --n >= 0) putc_cur(c);
+    putc_cur(0);
+}
+
 /**	**/
 void
 putws_cur(p)
