@@ -1,5 +1,5 @@
 /*
- * $Id: fzk.c,v 1.5.2.1 1999/02/08 03:10:59 yamasita Exp $
+ * $Id: fzk.c,v 1.5.2.2 1999/03/23 09:24:44 nakanisi Exp $
  */
 
 /*
@@ -30,8 +30,10 @@
  * Commentary:
  *
  * Change log:
+ *	Akitoshi MORISHIMA <ohm@rcac.tdi.co.jp>
+ *		MkLinux ͭ饤֥경˸߲Х
  *
- * Last modified date: 8,Feb.1999
+ * Last modified date: 22,Mar.1999
  *
  * Code:
  *
@@ -113,8 +115,6 @@ register	FILE	*fp;
 
 	fzk_tbl = fzk_ld(fp);
 	if (fzk_tbl != NULL) {
-		if (fp != NULL)
-			fclose(fp);
 #ifndef NO_FZK
 		link_job(fzk_tbl->fzklength, fzk_tbl);
 #endif
