@@ -1,5 +1,5 @@
 /*
- * $Id: init_w.c,v 1.19.2.1 1999/02/08 07:43:32 yamasita Exp $
+ * $Id: init_w.c,v 1.19.2.3 1999/04/19 06:05:25 nakanisi Exp $
  */
 
 /*
@@ -28,8 +28,10 @@
  * Commentary:
  *
  * Change log:
+ *	'99/04/19       TAOKA Satoshi - Ĳ һ<taoka@infonets.hiroshima-u.ac.jp>
+ *		index() 򥳥ȥȡ
  *
- * Last modified date: 8,Feb.1999
+ * Last modified date: 19,Apr.1999
  *
  * Code:
  *
@@ -78,7 +80,7 @@ env_state()
     char *p;
     char ret = '\0';
 #ifndef SYSVR2
-    extern char *index();
+/*    extern char *index(); */
 #else
     extern char *strchr();
 #endif
