@@ -1,5 +1,5 @@
 /*
- * $Id: jutil.c,v 1.10.2.1 1999/02/08 07:43:33 yamasita Exp $
+ * $Id: jutil.c,v 1.10.2.3 1999/04/19 06:05:25 nakanisi Exp $
  */
 
 /*
@@ -31,8 +31,10 @@
  * Commentary:
  *
  * Change log:
+ *	'99/04/19	TAOKA Satoshi - Ĳ һ<taoka@infonets.hiroshima-u.ac.jp>
+ *		srandom() 򥳥ȥȡ
  *
- * Last modified date: 8,Feb.1999
+ * Last modified date: 19,Apr.1999
  *
  * Code:
  *
@@ -624,7 +626,7 @@ int  (*error_handler)(), (*message_handler)();
     extern int srand();
     extern long rand();
 #else
-    extern int srandom();
+/*    extern int srandom(); */
     extern long random();
 #endif
     extern long time();
